@@ -1,30 +1,22 @@
-#[macro_use]
-extern crate lazy_static;
-
-pub mod activities;
-pub mod activity_queue;
-pub mod extensions;
-pub mod fetcher;
-pub mod http;
-pub mod migrations;
-pub mod objects;
-
-use crate::{extensions::signatures::PublicKey, fetcher::post_or_comment::PostOrComment};
+use crate::fetcher::post_or_comment::PostOrComment;
 use anyhow::{anyhow, Context};
 use lemmy_api_common::blocking;
-use lemmy_db_queries::{source::activity::Activity_, DbPool};
-use lemmy_db_schema::{
-  source::{activity::Activity, person::Person},
-  CommunityId,
-  DbUrl,
-};
-use lemmy_db_views_actor::community_person_ban_view::CommunityPersonBanView;
+use lemmy_db_schema::{newtypes::DbUrl, source::activity::Activity, DbPool};
 use lemmy_utils::{location_info, settings::structs::Settings, LemmyError};
-use serde::Serialize;
+use serde::{Deserialize, Deserializer};
 use std::net::IpAddr;
 use url::{ParseError, Url};
 
-static APUB_JSON_CONTENT_TYPE: &str = "application/activity+json";
+pub mod activities;
+pub(crate) mod activity_lists;
+pub(crate) mod collections;
+mod context;
+pub mod fetcher;
+pub mod http;
+pub(crate) mod mentions;
+pub mod migrations;
+pub mod objects;
+pub mod protocol;
 
 /// Checks if the ID is allowed for sending or receiving.
 ///
@@ -34,6 +26,8 @@ static APUB_JSON_CONTENT_TYPE: &str = "application/activity+json";
 /// - URL being in the allowlist (if it is active)
 /// - URL not being in the blocklist (if it is active)
 ///
+/// `use_strict_allowlist` should be true only when parsing a remote community, or when parsing a
+/// post/comment in a local community.
 pub(crate) fn check_is_apub_id_valid(
   apub_id: &Url,
   use_strict_allowlist: bool,
@@ -92,47 +86,23 @@ pub(crate) fn check_is_apub_id_valid(
   Ok(())
 }
 
-/// Common methods provided by ActivityPub actors (community and person). Not all methods are
-/// implemented by all actors.
-trait ActorType {
-  fn is_local(&self) -> bool;
-  fn actor_id(&self) -> Url;
-  fn name(&self) -> String;
-
-  // TODO: every actor should have a public key, so this shouldnt be an option (needs to be fixed in db)
-  fn public_key(&self) -> Option<String>;
-  fn private_key(&self) -> Option<String>;
-
-  fn get_shared_inbox_or_inbox_url(&self) -> Url;
-
-  /// Outbox URL is not generally used by Lemmy, so it can be generated on the fly (but only for
-  /// local actors).
-  fn get_outbox_url(&self) -> Result<Url, LemmyError> {
-    /* TODO
-    if !self.is_local() {
-      return Err(anyhow!("get_outbox_url() called for remote actor").into());
-    }
-    */
-    Ok(Url::parse(&format!("{}/outbox", &self.actor_id()))?)
+pub(crate) fn deserialize_one_or_many<'de, T, D>(deserializer: D) -> Result<Vec<T>, D::Error>
+where
+  T: Deserialize<'de>,
+  D: Deserializer<'de>,
+{
+  #[derive(Deserialize)]
+  #[serde(untagged)]
+  enum OneOrMany<T> {
+    One(T),
+    Many(Vec<T>),
   }
 
-  fn get_public_key(&self) -> Result<PublicKey, LemmyError> {
-    Ok(PublicKey {
-      id: format!("{}#main-key", self.actor_id()),
-      owner: self.actor_id(),
-      public_key_pem: self.public_key().context(location_info!())?,
-    })
-  }
-}
-
-#[async_trait::async_trait(?Send)]
-pub trait CommunityType {
-  fn followers_url(&self) -> Url;
-  async fn get_follower_inboxes(
-    &self,
-    pool: &DbPool,
-    settings: &Settings,
-  ) -> Result<Vec<Url>, LemmyError>;
+  let result: OneOrMany<T> = Deserialize::deserialize(deserializer)?;
+  Ok(match result {
+    OneOrMany::Many(list) => list,
+    OneOrMany::One(value) => vec![value],
+  })
 }
 
 pub enum EndpointType {
@@ -144,7 +114,7 @@ pub enum EndpointType {
 }
 
 /// Generates an apub endpoint for a given domain, IE xyz.tld
-fn generate_apub_endpoint_for_domain(
+pub fn generate_local_apub_endpoint(
   endpoint_type: EndpointType,
   name: &str,
   domain: &str,
@@ -160,15 +130,6 @@ fn generate_apub_endpoint_for_domain(
   Ok(Url::parse(&format!("{}/{}/{}", domain, point, name))?.into())
 }
 
-/// Generates the ActivityPub ID for a given object type and ID.
-pub fn generate_apub_endpoint(
-  endpoint_type: EndpointType,
-  name: &str,
-  protocol_and_hostname: &str,
-) -> Result<DbUrl, ParseError> {
-  generate_apub_endpoint_for_domain(endpoint_type, name, protocol_and_hostname)
-}
-
 pub fn generate_followers_url(actor_id: &DbUrl) -> Result<DbUrl, ParseError> {
   Ok(Url::parse(&format!("{}/followers", actor_id))?.into())
 }
@@ -192,65 +153,27 @@ pub fn generate_shared_inbox_url(actor_id: &DbUrl) -> Result<DbUrl, LemmyError>
   Ok(Url::parse(&url)?.into())
 }
 
+pub fn generate_outbox_url(actor_id: &DbUrl) -> Result<DbUrl, ParseError> {
+  Ok(Url::parse(&format!("{}/outbox", actor_id))?.into())
+}
+
 fn generate_moderators_url(community_id: &DbUrl) -> Result<DbUrl, LemmyError> {
   Ok(Url::parse(&format!("{}/moderators", community_id))?.into())
 }
 
-/// Takes in a shortname of the type dessalines@xyz.tld or dessalines (assumed to be local), and outputs the actor id.
-/// Used in the API for communities and users.
-pub fn build_actor_id_from_shortname(
-  endpoint_type: EndpointType,
-  short_name: &str,
-  settings: &Settings,
-) -> Result<DbUrl, ParseError> {
-  let split = short_name.split('@').collect::<Vec<&str>>();
-
-  let name = split[0];
-
-  // If there's no @, its local
-  let domain = if split.len() == 1 {
-    settings.get_protocol_and_hostname()
-  } else {
-    format!("{}://{}", settings.get_protocol_string(), split[1])
-  };
-
-  generate_apub_endpoint_for_domain(endpoint_type, name, &domain)
-}
-
 /// Store a sent or received activity in the database, for logging purposes. These records are not
 /// persistent.
-async fn insert_activity<T>(
+async fn insert_activity(
   ap_id: &Url,
-  activity: T,
+  activity: serde_json::Value,
   local: bool,
   sensitive: bool,
   pool: &DbPool,
-) -> Result<(), LemmyError>
-where
-  T: Serialize + std::fmt::Debug + Send + 'static,
-{
+) -> Result<(), LemmyError> {
   let ap_id = ap_id.to_owned().into();
   blocking(pool, move |conn| {
-    Activity::insert(conn, ap_id, &activity, local, sensitive)
+    Activity::insert(conn, ap_id, activity, local, sensitive)
   })
   .await??;
   Ok(())
 }
-
-async fn check_community_or_site_ban(
-  person: &Person,
-  community_id: CommunityId,
-  pool: &DbPool,
-) -> Result<(), LemmyError> {
-  if person.banned {
-    return Err(anyhow!("Person is banned from site").into());
-  }
-  let person_id = person.id;
-  let is_banned =
-    move |conn: &'_ _| CommunityPersonBanView::get(conn, person_id, community_id).is_ok();
-  if blocking(pool, is_banned).await? {
-    return Err(anyhow!("Person is banned from community").into());
-  }
-
-  Ok(())
-}
